@@ -1,22 +1,8 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
-   Copyright 2009 Thomas McGuire <mcguire@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2009 Thomas McGuire <mcguire@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 #include "stringutil.h"
 
@@ -39,7 +25,7 @@
 #include <QRegularExpression>
 #include <QStringList>
 #include <QUrlQuery>
-#include <kpimtextedit/textutils.h>
+#include <KPIMTextEdit/TextUtils>
 #include <KCodecs>
 using namespace KMime;
 using namespace KMime::Types;
@@ -186,7 +172,6 @@ QVector<QPair<QString, QString> > parseMailtoUrl(const QUrl &url)
     str = KCodecs::decodeRFC2047String(str);
     const QUrl newUrl = QUrl::fromUserInput(str);
 
-
     int indexTo = -1;
     //Workaround line with # see bug 406208
     const int indexOf = str.indexOf(QLatin1Char('?'));
@@ -229,9 +214,9 @@ QString stripSignature(const QString &msg)
 {
     // Following RFC 3676, only > before --
     // I prefer to not delete a SB instead of delete good mail content.
-    const QRegularExpression sbDelimiterSearch(QStringLiteral("(^|\n)[> ]*-- \n"));
+    static const QRegularExpression sbDelimiterSearch(QStringLiteral("(^|\n)[> ]*-- \n"));
     // The regular expression to look for prefix change
-    const QRegularExpression commonReplySearch(QStringLiteral("^[ ]*>"));
+    static const QRegularExpression commonReplySearch(QStringLiteral("^[ ]*>"));
 
     QString res = msg;
     int posDeletingStart = 1; // to start looking at 0
