@@ -1,19 +1,7 @@
 /*
-    Copyright (c) 2009 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2009 Kevin Ottens <ervin@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "pane.h"
@@ -129,7 +117,7 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
     const QAbstractProxyModel *proxyModel = qobject_cast<const QAbstractProxyModel *>(d->mSelectionModel->model());
 
     while (proxyModel) {
-        if (static_cast<const QAbstractItemModel *>(proxyModel) == d->mModel) {
+        if (proxyModel == d->mModel) {
             break;
         }
 
@@ -138,7 +126,7 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
 
         if (!nextProxyModel) {
             // It's the final model in the chain, so it is necessarily the sourceModel.
-            Q_ASSERT(qobject_cast<const QAbstractItemModel *>(proxyModel->sourceModel()) == d->mModel);
+            Q_ASSERT(proxyModel->sourceModel() == d->mModel);
             break;
         }
         proxyModel = nextProxyModel;
@@ -264,7 +252,6 @@ void Pane::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
         d->mActionMenu->addAction(action);
         d->mActionMenu->addSeparator();
 
-
         d->mMaxTabCreated = count();
         for (int i = 1; i < 10 && i <= count(); ++i) {
             d->addActivateTabAction(i);
@@ -274,22 +261,18 @@ void Pane::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
         QList<QKeySequence> prevShortcut;
 
         QString nextIcon, prevIcon;
-        if (QApplication::isRightToLeft())
-        {
+        if (QApplication::isRightToLeft()) {
             nextShortcut.append(KStandardShortcut::tabPrev());
             prevShortcut.append(KStandardShortcut::tabNext());
             nextIcon = QStringLiteral("go-previous-view");
             prevIcon = QStringLiteral("go-next-view");
-        }
-        else
-        {
+        } else {
             nextShortcut.append(KStandardShortcut::tabNext());
             prevShortcut.append(KStandardShortcut::tabPrev());
             nextIcon = QStringLiteral("go-next-view");
             prevIcon = QStringLiteral("go-previous-view");
         }
 
-
         d->mActivateNextTabAction = new QAction(i18n("Activate Next Tab"), this);
         d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("activate_next_tab"), d->mActivateNextTabAction);
         d->mActivateNextTabAction->setEnabled(false);
@@ -328,7 +311,6 @@ void Pane::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
         });
         d->mActionMenu->addAction(d->mMoveTabRightAction);
 
-
         d->mActionMenu->addSeparator();
 
         d->mCloseTabAction = new QAction(i18n("Close Tab"), this);
@@ -339,8 +321,6 @@ void Pane::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
         });
         d->mActionMenu->addAction(d->mCloseTabAction);
         d->mCloseTabAction->setEnabled(false);
-
-
     }
 }
 
