@@ -1,31 +1,8 @@
 /*
     This file is part of KMail, the KDE mail client.
-    Copyright (c) 2017 Sandro Knauß <sknauss@kde.org>
+    SPDX-FileCopyrightText: 2017 Sandro Knauß <sknauss@kde.org>
 
-    KMail is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    KMail is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "messagepartrendererfactory.h"
@@ -48,6 +25,16 @@
 
 using namespace MessageViewer;
 
+MessagePartRendererFactoryPrivate::~MessagePartRendererFactoryPrivate()
+{
+    QHashIterator<QByteArray, std::vector<RendererInfo> > i(m_renderers);
+    while (i.hasNext()) {
+        i.next();
+        auto renderInfo = i.value();
+        renderInfo.erase(renderInfo.begin(), renderInfo.end());
+    }
+}
+
 void MessagePartRendererFactoryPrivate::setup()
 {
     if (m_renderers.isEmpty()) {
@@ -181,6 +168,7 @@ QVector<MessagePartRendererBase *> MessagePartRendererFactory::renderersForPart(
     });
 
     QVector<MessagePartRendererBase *> r;
+    r.reserve(candidates.size());
     for (const auto &candidate : candidates) {
         r.push_back(candidate.renderer.data());
     }
