@@ -2,34 +2,11 @@
     urlhandlermanager.cpp
 
     This file is part of KMail, the KDE mail client.
-    Copyright (c) 2003      Marc Mutz <mutz@kde.org>
-    Copyright (C) 2002-2003, 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-    Copyright (c) 2009 Andras Mantia <andras@kdab.net>
+    SPDX-FileCopyrightText: 2003 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2002-2003, 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
+    SPDX-FileCopyrightText: 2009 Andras Mantia <andras@kdab.net>
 
-    KMail is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    KMail is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "urlhandlermanager.h"
@@ -46,17 +23,16 @@
 #include <MimeTreeParser/PartNodeBodyPart>
 
 #include <MessageCore/StringUtil>
-#include <Libkdepim/BroadcastStatus>
-#include <LibkdepimAkonadi/OpenEmailAddressJob>
+#include <PimCommon/BroadcastStatus>
+#include <Akonadi/Contact/OpenEmailAddressJob>
 
 #include <Akonadi/Contact/ContactSearchJob>
 
 #include <KMime/Content>
 #include <KEmailAddress>
-#include <kmbox/mbox.h>
+#include <KMbox/MBox>
 #include "messageflags.h"
 
-#include <KRun>
 #include <KIconLoader>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -602,7 +578,7 @@ static QString searchFullEmailByUid(const QString &uid)
 
 static void runKAddressBook(const QUrl &url)
 {
-    KPIM::OpenEmailAddressJob *job = new KPIM::OpenEmailAddressJob(url.path(), nullptr);
+    Akonadi::OpenEmailAddressJob *job = new Akonadi::OpenEmailAddressJob(url.path(), nullptr);
     job->start();
 }
 
@@ -642,7 +618,7 @@ bool ContactUidURLHandler::handleContextMenuRequest(const QUrl &url, const QPoin
             QClipboard *clip = QApplication::clipboard();
             clip->setText(fullEmail, QClipboard::Clipboard);
             clip->setText(fullEmail, QClipboard::Selection);
-            KPIM::BroadcastStatus::instance()->setStatusMsg(i18n("Address copied to clipboard."));
+            PimCommon::BroadcastStatus::instance()->setStatusMsg(i18n("Address copied to clipboard."));
         }
 #endif
     }
@@ -918,8 +894,8 @@ bool KRunURLHandler::handleClick(const QUrl &url, ViewerPrivate *w) const
         || (scheme == QLatin1String("help")) || (scheme == QLatin1String("vnc"))
         || (scheme == QLatin1String("smb")) || (scheme == QLatin1String("fish"))
         || (scheme == QLatin1String("news")) || (scheme == QLatin1String("tel"))) {
-        KPIM::BroadcastStatus::instance()->setTransientStatusMsg(i18n("Opening URL..."));
-        QTimer::singleShot(2000, KPIM::BroadcastStatus::instance(), &KPIM::BroadcastStatus::reset);
+        PimCommon::BroadcastStatus::instance()->setTransientStatusMsg(i18n("Opening URL..."));
+        QTimer::singleShot(2000, PimCommon::BroadcastStatus::instance(), &PimCommon::BroadcastStatus::reset);
 
         QMimeDatabase mimeDb;
         auto mime = mimeDb.mimeTypeForUrl(url);
