@@ -1,21 +1,9 @@
 /*
-  Copyright (c) 1997 Markus Wuebben <markus.wuebben@kde.org>
-  Copyright (C) 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Copyright (c) 2009 Andras Mantia <andras@kdab.net>
+  SPDX-FileCopyrightText: 1997 Markus Wuebben <markus.wuebben@kde.org>
+  SPDX-FileCopyrightText: 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
+  SPDX-FileCopyrightText: 2009 Andras Mantia <andras@kdab.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef MAILVIEWER_P_H
@@ -26,6 +14,7 @@
 #include "viewer.h" //not so nice, it is actually for the enums from MailViewer
 #include <PimCommon/ShareServiceUrlManager>
 #include "messageviewer/viewerplugininterface.h"
+#include "widgets/opensavedfilefolderwidget.h"
 #include <WebEngineViewer/CheckPhishingUrlUtil>
 
 #include <AkonadiCore/item.h>
@@ -87,13 +76,13 @@ class WebEnginePartHtmlWriter;
 class HtmlStatusBar;
 class ScamDetectionWarningWidget;
 class MimePartTreeView;
-class OpenAttachmentFolderWidget;
 class HeaderStyleMenuManager;
 class ViewerPluginToolManager;
 class SubmittedFormWarningWidget;
 class MailSourceWebEngineViewer;
 class MailTrackingWarningWidget;
 class ShowNextMessageWidget;
+class DeveloperToolDialog;
 /**
 \brief Private class for the Viewer, the main widget in the messageviewer library.
 
@@ -417,7 +406,7 @@ public:
     void goOnline();
     void goResourceOnline();
 
-    void showOpenAttachmentFolderWidget(const QList<QUrl> &urls);
+    void showSavedFileFolderWidget(const QList<QUrl> &urls, MessageViewer::OpenSavedFileFolderWidget::FileType fileType);
 
     Q_REQUIRED_RESULT bool mimePartTreeIsEmpty() const;
 
@@ -562,6 +551,7 @@ public Q_SLOTS:
     void slotResetMessageDisplayFormat();
 
     void slotGeneralFontChanged();
+    void slotShowDevelopmentTools();
 
 Q_SIGNALS:
     void showStatusBarMessage(const QString &message);
@@ -648,14 +638,17 @@ public:
     KToggleAction *mToggleFixFontAction = nullptr;
     KToggleAction *mToggleDisplayModeAction = nullptr;
     KToggleAction *mToggleMimePartTreeAction = nullptr;
+    QAction *mDevelopmentToolsAction = nullptr;
     QAction *mSpeakTextAction = nullptr;
     QAction *mCopyImageLocation = nullptr;
+    QAction *mShareTextAction = nullptr;
     QUrl mClickedUrl;
     QUrl mImageUrl;
     HtmlWriter *mHtmlWriter = nullptr;
     /** Used only to be able to connect and disconnect finished() signal
       in printMsg() and slotPrintMsg() since mHtmlWriter points only to abstract non-QObject class. */
     QPointer<WebEnginePartHtmlWriter> mPartHtmlWriter;
+    QPointer<DeveloperToolDialog> mDeveloperToolDialog;
 
     int mLevelQuote;
     bool mDecrytMessageOverwrite = false;
@@ -678,7 +671,7 @@ public:
     Akonadi::Item::Id mPreviouslyViewedItemId;
 
     MessageViewer::ScamDetectionWarningWidget *mScamDetectionWarning = nullptr;
-    MessageViewer::OpenAttachmentFolderWidget *mOpenAttachmentFolderWidget = nullptr;
+    MessageViewer::OpenSavedFileFolderWidget *mOpenSavedFileFolderWidget = nullptr;
     MessageViewer::SubmittedFormWarningWidget *mSubmittedFormWarning = nullptr;
     MessageViewer::MailTrackingWarningWidget *mMailTrackingWarning = nullptr;
     KPIMTextEdit::TextToSpeechWidget *mTextToSpeechWidget = nullptr;
